@@ -12,14 +12,14 @@ feature 'Utility to create IO::Handle-ish objects', -default => 1,
 ;
 feature 'Core and Essential Tools', -default => 1,
   'PSGI', '1.03',
-  'Plack', '0.9929',
-  'CGI::PSGI', '0.10',
-  'CGI::Emulate::PSGI', '0.06',
+  'Plack', '0.9934',
+  'CGI::PSGI', '0.11',
+  'CGI::Emulate::PSGI', '0.08',
   'CGI::Compile', '0.11',
 ;
 feature 'Recommended PSGI Servers and Plack handlers', -default => 1,
   'HTTP::Server::Simple::PSGI', '0.14',
-  'Starman', '0.1006',
+  'Starman', '0.2004',
   'Twiggy', '0.1005',
   'Starlet', '0.08',
   'Corona', '0.1004',
@@ -36,13 +36,14 @@ feature 'In-Development PSGI Servers', -default => 0,
 feature 'Recommended middleware components', -default => 1,
   'Plack::Middleware::Deflater', '0.03',
   'Plack::Middleware::Session', '0.11',
-  'Plack::Middleware::Debug', '0.07',
+  'Plack::Middleware::Debug', '0.09',
   'Plack::Middleware::Header', '0.03',
   'Plack::Middleware::Auth::Digest', '0.03',
   'Plack::App::Proxy', '0.15',
   'Plack::Middleware::ReverseProxy', '0.06',
+  'Plack::Middleware::ConsoleLogger', '0.01',
 ;
-feature 'Middleware Components', -default => 0,
+feature 'Extra Middleware Components', -default => 0,
   'Plack::Middleware::JSConcat', '0.29',
   'Plack::Middleware::File::Sass', '0.01',
 ;
